package produto;

import setor.Setor;
import pontoVenda.*;

public class CadastroProduto {


private RepositorioProduto rep;


/**  * Construtor da classe CadastroProduto
     *
     * @param repProduto    Repositorio de Produtos criado na fachada
     */
public CadastroProduto ( RepositorioProduto repProduto) {
        rep = repProduto;
   }


  // ................. MTODOS ....................


  //   Inserir Produto

    public void inserirProduto(Produto produto) throws ProdutoJaCaException  {
        rep.inserirProduto(produto);
    }

  // Excluir  Produto

    public void excluirProduto(Produto produto) throws ProdutoNaoCaException {
       rep.excluirProduto(produto);
    }

   // Procura Produto e devolve True ou False

    public boolean procurarProduto(Produto produto) {
       return rep.procurarProduto(produto);

    }

    //  Inserir Perfil em um  Produto

    /*
     * @param nomeProduto       Nome do Produto
     * @param codigo            Cdigo do produto (com aquele perfil)
     * @param sexo              Sexo dos usurios que podem fazer uso daquele perfil do produto
     * @param idMin             Idade Minima dos Usuarios que podem fazer uso daquele perfil do produto
     * @param idMax             Idade Mxima dos Usuarios que podem fazer uso daquele perfil do produto
     * @param marca             Marca do Perfil do Produto
     * @param detalhe           Detalhes especficos do Perfil do produto
    */


    public void inserirPerfilProduto(Produto p, PerfilProduto pp)
     throws ProdutoNaoCaException, PerfilJaCaException {

        rep.inserirPerfilProduto(p, pp);
    }


    // Excluir Perfil do Produto
     /*
     * @param nomeProduto       Nome do Tipo de Produto
     * @param codigoProduto     Cdigo do produto (com aquele perfil)
     */
    public void excluirPerfilProduto(Produto p, PerfilProduto pp)
      throws ProdutoNaoCaException, PerfilNaoCaException {
        rep.excluirPerfilProduto(p, pp);
    }

     //  Inserir Oferta de um Produto

    /*
     * @param nomeProduto   Nome do  Produto
     * @param codigo            Cdigo do produto (com aquele perfil)
     * @param loja              Loja que oferta o produto
     * @param preco             Preo do produto na Loja
    */


    public void inserirOfertaProduto(Produto p, PerfilProduto pp, OfertaProduto op)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaJaCaException {

        rep.inserirOfertaProduto(p, pp, op);
    }


    // Excluir Oferta de um Produto
     /*
     * @param nomeProduto   Nome do Produto
     * @param codigo            Cdigo do produto (com aquele perfil)
     * @param loja              Loja que oferta o produto
     */

    public void excluirOfertaProduto(Produto p, PerfilProduto pp, OfertaProduto op)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaNaoCaException {
        rep.excluirOfertaProduto(p, pp, op);
    }

    // Altera o preo da Oferta

    public void alterarPrecoOfertaProduto(Produto p, PerfilProduto pp,
      OfertaProduto op, double novoPreco)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaNaoCaException{

      rep.alterarPrecoOfertaProduto(p, pp, op, novoPreco);
      }


       //  Devolve um array com Produtos

    public Produto[] getArrayProduto() {
        return rep.getArrayProduto();
    }


    //  Devolve um array com Produtos de um Setor

    public Produto[] getArrayProdutoSetor(Setor setor) {
        return rep.getArrayProdutoSetor(setor);
    }

    //  Devolve um array com Perfis de um Produto

    public PerfilProduto[] getArrayPerfilProduto(Produto p) {
        return rep.getArrayPerfilProduto(p);
    }

    //  Devolve um array com Ofertas de um Produto

    public OfertaProduto[] getArrayOfertaProduto(Produto p, PerfilProduto pp) {
        return rep.getArrayOfertaProduto(p, pp);
    }

    public Produto[]  selecionarProduto(Produto produto) {
        return rep.selecionarProduto(produto);
    }

    /** Este metodo devolve um conjunto de produtos e alguns de seus perfis
     *  para criacao de novos objetos de acordo com a busca do usuario
     *
     * @param produto   Contem as caracteristicas do produto/perfil buscado
     *
     *
     */

    public Produto[] filtrarProdutos(Produto produto) throws PerfilJaCaException {
      Produto[] resultado = rep.selecionarProduto(produto);
      int i=0;
      PerfilProduto pp = null;
      PerfilProduto[] pps = produto.getArrayPerfilProduto();

      if (pps[0] != null)
        pp = pps[0];

      Produto p;
      Produto[] filtro = new Produto[100];
      PerfilProduto[] subgrupo = new PerfilProduto[100];
      RepositorioPerfilProdutoLista rppl = new RepositorioPerfilProdutoLista();
      RepositorioPerfilProdutoLista perfisOk;
      while (resultado[i] != null){
        subgrupo = resultado[i].selecionarPerfilProduto(pp);
        perfisOk = rppl.arrayParaLista(subgrupo);
        p = new Produto(produto.getNomeProduto(),produto.getSetorProduto(),
                        perfisOk);
        filtro[i] = p;
        i=i+1;
        }
        return filtro;

  } // fecha o metodo


}   // Fecha a classe  CadastroProduto
