package produto;

import pontoVenda.PontoVenda;

public class PerfilProduto {




  private int codigoProduto;         // Codigo do Produto dado pelo Fabricante (com aquele perfil)
  private String sexo;               // Sexo dos usurios que podem fazer uso do produto
  private int idadeMinima;           // Idade Minima dos Usuarios do Produto
  private int idadeMaxima;           // Idade Maxima dos Usuarios do Produto
  private Marca marca;               // Marca do Produto
  private String detalhe;            // Detalhamento geral do produto
  private RepositorioOfertaProdutoLista ofertaProdutos;     // Coleo de Preo por pontoVenda que dispe do Produto


  /**  *  Construtor da classe PerfilProduto.
     *

     * @param codigo   Cdigo do produto (com aquele perfil)
     * @param sexo     Sexo dos usurios que podem fazer uso do produto (com aquele perfil)
     * @param idMin    Idade Minima dos Usuarios do Produto (com aquele perfil)
     * @param idMax    Idade Mxima dos Usuarios do Produto  (com aquele perfil)
     * @param marca    Marca do Produto
     * @param detalhe  Detalhes especficos do produto  (com aquele perfil)
     */

    public PerfilProduto(int codigo, String sexo, int idMin,
                    int idMax, Marca marca, String detalhe){
        this.codigoProduto = codigo;
        this.sexo = sexo;
        this.idadeMinima = idMin;
        this.idadeMaxima = idMax;
        this.marca = marca;
        this.detalhe = detalhe;
        ofertaProdutos = new RepositorioOfertaProdutoLista();
    }

    public PerfilProduto() {
     }


  // ........ MTODOS ........................


  //   Retorna o codigo do Produto  (com aquele perfil)

    public int getCodigoProduto() {
        return this.codigoProduto;
    }

  // Retorna o Sexo dos usurios do Produto

    public String getSexo() {
        return this.sexo;
    }

  // Retorna a idade mnima dos usurios do Produto

    public int getIdadeMinima() {
        return this.idadeMinima;
    }

   // Retorna a idade mxima dos usurios do Produto

    public int getIdadeMaxima() {
        return this.idadeMaxima;
    }

   // Retorna a marca do Produto

    public Marca getMarca() {
        return this.marca;
    }

  // Retorna detalhes do Produto

    public String getDetalhe() {
        return this.detalhe;
    }

  /** Altera detalhes do produto (com aquele perfil)
     *
     * @param           nova descrio do detalhe
     */

     public void setDetalhe(String novoDetalhe) {
         this.detalhe = novoDetalhe;
     }

  /** Insere uma nova Oferta do Produto
     *
     * @param           pontoVenda que possui a Oferta do Produto
     * @param           preo da oferta na pontoVenda
     */
     public void inserirOfertaProduto(OfertaProduto ofertaProduto)
       throws OfertaJaCaException {
        ofertaProdutos.inserirOfertaProduto(ofertaProduto);
    }

    /**
     * Exclui uma Oferta do Produto
     *
     * @param           pontoVenda que possui a oferta
     */
    public void excluirOfertaProduto(OfertaProduto ofertaProduto)
       throws OfertaNaoCaException {
        ofertaProdutos.excluirOfertaProduto(ofertaProduto);
    }

       /**
     * Altera o preco de uma Oferta do produto
     *
     * @param           pontoVenda que possui a oferta
     * @param           novo preo da Oferta
     */

    public void alterarPrecoOfertaProduto(OfertaProduto ofertaProduto, double novoPreco)
       throws OfertaNaoCaException {
        ofertaProdutos.alterarPrecoOfertaProduto(ofertaProduto, novoPreco);
    }

    // Retorna um array com um conjunto de Ofertas do Produto

     public OfertaProduto[] getArrayOfertaProduto(){
       return ofertaProdutos.getArrayOfertaProduto();
       }

 // Mtodo Match - Verifica se o objeto atende s condies
 // especificadas num objeto enviado

  public boolean match(PerfilProduto p) {
   Marca marca, marcaAtual;
   boolean resultado = true;

   marcaAtual = this.getMarca();
   marca = p.getMarca();



   if (p != null) {   //  1o. if
    if(p.getSexo() != null)  {  // 2o. if
     if (this.getSexo() != p.getSexo()) { // 3o. if
      return resultado = false;
     } // fecha o 3o. if
    } // fecha 2o. if
    if (p.getIdadeMinima() > 0) {  // 4o.  if
     if (this.getIdadeMinima() > p.getIdadeMinima()) { // 5o.if
      return resultado = false;
     } // fecha o 5o. if
    } // fecha o 4o. if
    if (p.getIdadeMaxima() > 0) {  // 6o.  if
     if (this.getIdadeMaxima() < p.getIdadeMaxima()) { // 7o.if
      return resultado = false;
     } // fecha o 7o. if
    } // fecho o 6o. if
    if (!marcaAtual.match(marca)) { // 8o.  if
      return resultado = false;
    } // fecha 8o. if
    return resultado;

   } // fecha 1o. if
   else  // else do 1o. if
     return resultado;

  } // fecha o metodo


}   // Fecha a classe


