package produto;

import setor.Setor;
import pontoVenda.PontoVenda;

/*
 Esta Classe modela um conjunto, em forma de lista, de Produtos.
*/


interface RepositorioProduto {


// .............. MTODOS ...........................


/* Insere um novo Produto na lista.
     *
     * @param           Um Produto a ser inserido.
     */
    public void inserirProduto(Produto produto) throws ProdutoJaCaException;



/* Exclui uma TipoProduto da lista.
     *
     * @param           TipoProduto a ser excluida.
     */
    public void excluirProduto(Produto produto) throws ProdutoNaoCaException;



/* Procura se um dado Produto pertence  lista.
     *
     * @param           Nome do Produto a ser procurado.
     * @return          Resposta se o arquivo existe.
     */
    public boolean procurarProduto(Produto produto);



    // Inclui Perfil de um Produto

    public void inserirPerfilProduto(Produto produto, PerfilProduto perfilProduto)
     throws ProdutoNaoCaException, PerfilJaCaException;



/* Exclui Perfil de Produto
     *
     * @param nomeProduto   Nome do Produto
     * @param codigoProduto     Cdigo do produto (com aquele perfil)
     */
    public void excluirPerfilProduto(Produto produto, PerfilProduto perfilProduto)
     throws ProdutoNaoCaException, PerfilNaoCaException;


/* Inclui Oferta de um Produto
     *
     */
    public void inserirOfertaProduto(Produto produto, PerfilProduto perfilProduto,
                                     OfertaProduto ofertaProduto)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaJaCaException;



/*  Exclui Oferta de um Produto
     *
     */

    public void excluirOfertaProduto(Produto produto, PerfilProduto perfilProduto,
                                     OfertaProduto ofertaProduto)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaNaoCaException;

/* Altera o preo de uma Oferta de um Produto
      *
      */

    public void alterarPrecoOfertaProduto(Produto produto, PerfilProduto perfilProduto,
                                 OfertaProduto ofertaProduto, double novoPreco)
      throws ProdutoNaoCaException, PerfilNaoCaException, OfertaNaoCaException;



/*  Retorna um array de produto
      *
      */

    public  Produto[]  getArrayProduto();



/*  Retorna um array de produtos de um Setor
      *
      */

    public  Produto[]  getArrayProdutoSetor(Setor setor);



/*  Retorna um array com Perfis de Produto de um Produto
      *
      */

    public PerfilProduto[] getArrayPerfilProduto(Produto produto);



/*   Retorna um array de Ofertas de um Produto
       *
       */

    public OfertaProduto[] getArrayOfertaProduto(Produto produto, PerfilProduto perfilProduto);


/*  Retorna um array com Seleo de Produtos
      *
      */

    public Produto[] selecionarProduto(Produto produto);



} // Fecha a Interface RepositorioProduto


